@@ -12,60 +12,34 @@ neon_data <- function(product,
                       api = "https://data.neonscience.org/api/v0", 
                       .token = Sys.getenv("NEON_TOKEN")){
   
-  start_date <- as.Date(start_date)
-  end_date <- as.Date(end_date)
-  
-  ## A single API call to sites, includes product & month at each site    
-  sites_df <- neon_sites(api)
-  dataProducts <- do.call(rbind, sites_df$dataProducts)
-  
-  ## Consider all/only the sites including the requested product.
-  ## The DataUrl column gives the API endpoint data/{ProductCode}/{SiteCode}{Month}
-  available <- dataProducts[dataProducts$dataProductCode %in% product,]
-  
-  data_api <- unlist(available$availableDataUrls)
-  
-  product_regex <- "DP\\d\\.\\d{5}\\.\\d{3}"
-  regex <- paste0(api, "/data/", product_regex, "/(\\w+)/(\\d{4}-\\d{2})$")
-  
-  ## Filter by time -- year-month is included at end of data_api list
-  dates <- as.Date(gsub(regex, "\\2-01", data_api))
-  if(!is.na(start_date)){
-    data_api <- data_api[dates >= start_date]
-  }
-  if(!is.na(end_date)){
-    data_api <- data_api[dates <= end_date]
-  }  
-  
-  ## Filter by site
-  data_sites <- gsub(regex, "\\1", data_api)
-  if(!all(is.na(site))){
-    data_api <- data_api[data_sites %in% site]
-  }
-  
-  if(length(data_api) == 0){
-    message("No files to download.")
-    return(invisible(NULL))
-  }
+  data_api <- data_api_queries(product = product, 
+                               start_date = start_date, 
+                               end_date = end_date, 
+                               site = site,
+                               quiet = quiet,
+                               api = api,
+                               .token = .token)
   
   ## Adjust for rate-limiting
-  batch <- 1000                 # authenticated
-  if(.token == "") batch <- 200 # unauthenticated
+  batch <- 950                 # authenticated
+  if(.token == "") batch <- 150 # unauthenticated
   
   
   ## Extract the file list from the data endpoint.  O(sites * months) calls
   pb <- progress::progress_bar$new(
-    format = "  querying API [:bar] :percent eta: :eta",
+    format = paste("  requesting", product, 
+                   "from API [:bar] :percent in :elapsed, eta: :eta"),
     total = length(data_api), 
-    clear = FALSE, width= 60)
+    clear = FALSE, width= 80)
   
   resp <- vector("list", length = length(data_api))
   for(i in seq_along(data_api)){
     if(!quiet){ pb$tick() }
-    resp[[i]] <- httr::GET(data_api[[i]], httr::add_headers("X-API-Token" = .token))
+    resp[[i]] <- httr::GET(data_api[[i]],
+                           httr::add_headers("X-API-Token" = .token))
     if(i %% batch == 0){
-      message("\nNEON rate limiting enforced, pausing for 100s\n")
-      Sys.sleep(101)
+      if(!quiet) message("  NEON rate limiting enforced, pausing for 100s\n")
+      Sys.sleep(105)
     }
   }
   
@@ -99,3 +73,55 @@ neon_warn_http_errors <- function(x){
 ## Hence, we warn on these errors but will continue with any other downloads in the list.
 
 
+## prepare a vector of API queries
+data_api_queries <- function(product, 
+                            start_date = NA,
+                            end_date = NA,
+                            site = NA,
+                            quiet = FALSE,
+                            api = "https://data.neonscience.org/api/v0", 
+                            .token = Sys.getenv("NEON_TOKEN")){
+  
+  start_date <- as.Date(start_date)
+  end_date <- as.Date(end_date)
+  
+  ## A single API call to sites, includes product & month at each site    
+  sites_df <- neon_sites(api)
+  dataProducts <- do.call(rbind, sites_df$dataProducts)
+  
+  ## Consider all/only the sites including the requested product.
+  ## The DataUrl column gives the API endpoint data/{ProductCode}/{SiteCode}{Month}
+  available <- dataProducts[dataProducts$dataProductCode %in% product,]
+  
+  data_api <- unlist(available$availableDataUrls)
+  
+  product_regex <- "DP\\d\\.\\d{5}\\.\\d{3}"
+  regex <- paste0(api, "/data/", product_regex, "/(\\w+)/(\\d{4}-\\d{2})$")
+  
+  ## Filter by time -- year-month is included at end of data_api list
+  dates <- as.Date(gsub(regex, "\\2-01", data_api))
+  if(!is.na(start_date)){
+    data_api <- data_api[dates >= start_date]
+  }
+  if(!is.na(end_date)){
+    data_api <- data_api[dates <= end_date]
+  }  
+  
+  ## Filter by site
+  data_sites <- gsub(regex, "\\1", data_api)
+  if(!all(is.na(site))){
+    data_api <- data_api[data_sites %in% site]
+  }
+  
+  if(length(data_api) == 0){
+    if(!quiet) message("  No files to download.")
+    return(invisible(NULL))
+  }
+  data_api
+}
+
+
+
+
+
+
