@@ -10,19 +10,20 @@
 #' 
 neon_store <- function(table = NA,
                        product = NA,
+                       type = NA,
                        dir = neon_dir(),
-                       n = 100L,
+                       n = 500L,
                        quiet = FALSE, 
                        ...)
 {
   
   index <- neon_index(table = table,
                       product = product,
-                      hash = "md5",
+                      type = type,
                       dir = dir,
-                      ext = "csv",
                       deprecated = FALSE)
   
+  index <- index[index$ext == "h5" | index$ext == "csv",]
   
   if(is.null(index)) index <- data.frame()
   if(nrow(index) == 0){
@@ -80,8 +81,12 @@ stackable_tables <- function(tables){
 }
 
 
-db_chunks <- function(con, files, table, 
-                       n = 200L, quiet = FALSE, ...){
+db_chunks <- function(con, 
+                      files, 
+                      table, 
+                       n = 100L, 
+                      quiet = FALSE,
+                      ...){
   
   if(length(files)==0) return(NULL)
   
@@ -89,19 +94,26 @@ db_chunks <- function(con, files, table,
   if(length(files) %% n > 0)  ## and the remainder
     total <- total + 1
   
+  
+  progress <- !quiet
   ## all files in one go
   if(total == 1){
     df <- neon_stack(files = files,
                      keep_filename = TRUE,
                      sensor_metadata = TRUE,
                      altrep = FALSE,
-                     progress = FALSE,
+                     progress = progress,
                      ...)
-    DBI::dbWriteTable(con, table, df, append = TRUE)
+    if(!is.null(df)){
+      DBI::dbWriteTable(con, table, df, append = TRUE)
+    }
     return(invisible(con))
   }
   
-  ## Otherwise do chinks
+  if(total > 4){
+    progress <- FALSE
+  }
+  ## Otherwise do chunks
   pb <- progress::progress_bar$new(
     format = paste("  importing", table,
                    "[:bar] :percent in :elapsed, eta: :eta"),
@@ -110,15 +122,17 @@ db_chunks <- function(con, files, table,
     show_after = 0,
     width = 80)
   
-
+  if(!quiet && progress) 
+    message(paste("processing files in", total, "chunks."))
   for(i in 0:(total-1)){
-    if(!quiet) pb$tick()
+    if(!quiet && progress) message(paste("chunk", i+1, ":"))
+    if(!quiet && !progress) pb$tick()
     chunk <- na_omit(files[ (i*n+1):((i+1)*n) ])
     df <- neon_stack(files = chunk,
                      keep_filename = TRUE,
                      sensor_metadata = TRUE, 
                      altrep = FALSE,
-                     progress = FALSE)
+                     progress = progress)
     DBI::dbWriteTable(con, table, df, append = TRUE)  
   }
   return(invisible(con))
